SplashView class

Inheritance

Constructors

SplashView({Key? key, BackgroundImageDecoration? backgroundImageDecoration, Color? backgroundColor, Gradient? gradient, Widget? title, Widget? subtitle, Widget? loadingIndicator, bool bottomLoading = false, Duration? duration = const Duration(seconds: 3), Done? done, bool showStatusBar = false})
const

Properties

backgroundColor → Color?
Background color of the splash view.
final
backgroundImageDecoration → BackgroundImageDecoration?
Background image of the splash view.
final
bottomLoading → bool
Show loading indicator on the bottom of the splash view.
final
done → Done?
Done widget to redirect to the next page.
final
duration → Duration?
Duration of redirecting to the next page.
final
gradient → Gradient?
Gradient background of the splash view.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
loadingIndicator → Widget?
Loading indicator of the splash view.
final
Logo of the splash view.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showStatusBar → bool
Show and hide app status/navigation bar on the splash view.
final
subtitle → Widget?
Subtitle of the splash view.
final
title → Widget?
Title of the splash view.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<SplashView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited